
"""Init script for webezy.io template PubSubTs
Generated thanks to -

                 _                           _        
 __      __ ___ | |__    ___  ____ _   _    (_)  ___  
 \ \ /\ / // _ \| '_ \  / _ \|_  /| | | |   | | / _ \ 
  \ V  V /|  __/| |_) ||  __/ / / | |_| | _ | || (_) |
   \_/\_/  \___||_.__/  \___|/___| \__, |(_)|_| \___/ 
                                   |___/              



Author: Amit Shmulevitch
"""
# Main webezyio class to create gRPC services programmatically
# (Same inteface that webezyio cli is built as wrapper for
# WebezyArchitect whenever you generate new resource / create new project)
from webezyio.architect import WebezyArchitect

# Some common utils modules to help us build the services faster
# and adds an validations to object before they created
from webezyio.commons import helpers, file_system

# Webezy proto modules also helps us here to construct our services
# gRPC used to create another gRPC ! :)
from webezyio.commons.protos.webezy_pb2 import Language, WebezyContext, WebezyFileContext

# Default system imports
import os
import sys
import argparse
import zlib

    
"""Initialize constants and WebezyArchitect class"""
parser = argparse.ArgumentParser(
                    prog = 'PubSubTs',
                    description = 'What the program does',
                    epilog = 'Text at the bottom of help')
parser.add_argument('--domain',default='webezy')           # optional argument
parser.add_argument('--project-name',default='PubSubTs')           # optional argument

args = parser.parse_args()

# Constants
_PATH = file_system.join_path(os.getcwd(), 'webezy.json') 
_DOMAIN = args.domain
_PROJECT_NAME = args.project_name
_SERVER_LANGUAGE = Language.Name(Language.typescript)
_HOST = 'localhost'
_PORT = 50051

# Initializing WebezyArchitect class which we going to interact with
# It is used to create all of our 'webezyio' resources
_architect = WebezyArchitect(path=_PATH,
                             domain=_DOMAIN,
                             project_name=_PROJECT_NAME)
_architect.SetConfig({'host': _HOST, 'port': _PORT})
_architect.SetDomain(_DOMAIN)
    
"""Project specific configurations"""
    
# Init all the client to be used with your services
# Here we configured a python + typescript clients to be created with our services    
_clients = [{'language': 'python', 'out_dir': file_system.join_path(_PATH, 'clients', Language.Name(Language.python))}, {'language': 'typescript', 'out_dir': file_system.join_path(_PATH, 'clients', Language.Name(Language.typescript))}]
    
# Adding the base project data
_project = _architect.AddProject(server_language=_SERVER_LANGUAGE,
                                 clients=_clients)

# NOTE - that every call to WebezyArchitect executions
# it will return the proto generated class of that object
# which can be used to enrich the webezy base structure
# or debug easly whats going on beneath the surface
# print(type(_project))
# <class 'webezy_pb2.Project'>

    
# Creating enums values

        
# Creating enums   
 
        
"""Packages and thier resources"""
# Construct fields    

# Constructing a field for [webezy_PubSubPackage_v1_ConsumeTopic_topic]
_field_webezy_PubSubPackage_v1_ConsumeTopic_topic = helpers.WZField(name='topic',
                              description='This is the topic id to consume from',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Constructing a field for [webezy_PubSubPackage_v1_ConsumeTopic_topics]
_field_webezy_PubSubPackage_v1_ConsumeTopic_topics = helpers.WZField(name='topics',
                              description='',
                              label='LABEL_REPEATED',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Constructing a field for [webezy_PubSubPackage_v1_PublishEvent_timestamp]
_field_webezy_PubSubPackage_v1_PublishEvent_timestamp = helpers.WZField(name='timestamp',
                              description='The time event has been triggered',
                              label='LABEL_OPTIONAL',
                              type='TYPE_MESSAGE',
                              message_type='google.protobuf.Timestamp',
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Constructing a field for [webezy_PubSubPackage_v1_PublishEvent_topic]
_field_webezy_PubSubPackage_v1_PublishEvent_topic = helpers.WZField(name='topic',
                              description='A topic to publish the event',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Constructing a field for [webezy_PubSubPackage_v1_PublishEvent_event]
_field_webezy_PubSubPackage_v1_PublishEvent_event = helpers.WZField(name='event',
                              description='The event data',
                              label='LABEL_OPTIONAL',
                              type='TYPE_MESSAGE',
                              message_type='google.protobuf.Struct',
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Constructing a field for [webezy_PubSubPackage_v1_Topic_name]
_field_webezy_PubSubPackage_v1_Topic_name = helpers.WZField(name='name',
                              description='The topic name (Must be unique - See list of active topics with ListTopic RPC)',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Constructing a field for [webezy_PubSubPackage_v1_CreateTopicResponse_status]
_field_webezy_PubSubPackage_v1_CreateTopicResponse_status = helpers.WZField(name='status',
                              description='A human readable status of process',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Constructing a field for [webezy_PubSubPackage_v1_PublishEventResponse_status]
_field_webezy_PubSubPackage_v1_PublishEventResponse_status = helpers.WZField(name='status',
                              description='A human readable status of process',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Constructing a field for [webezy_PubSubPackage_v1_DropTopicResponse_topic]
_field_webezy_PubSubPackage_v1_DropTopicResponse_topic = helpers.WZField(name='topic',
                              description='The topic unique name to be dropped from queue',
                              label='LABEL_OPTIONAL',
                              type='TYPE_STRING',
                              message_type=None,
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Constructing a field for [webezy_PubSubPackage_v1_DropTopicRequest_topic]
_field_webezy_PubSubPackage_v1_DropTopicRequest_topic = helpers.WZField(name='topic',
                              description='The topic which we want to drop',
                              label='LABEL_OPTIONAL',
                              type='TYPE_MESSAGE',
                              message_type=_DOMAIN + '.PubSubPackage.v1.Topic',
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Constructing a field for [webezy_PubSubPackage_v1_DropTopicRequest_force]
_field_webezy_PubSubPackage_v1_DropTopicRequest_force = helpers.WZField(name='force',
                              description='If true it will drop the connection even if there are live consumers for the same topic, else it will fail the drop process',
                              label='LABEL_OPTIONAL',
                              type='TYPE_BOOL',
                              message_type=None,
                              enum_type=None,
                              key_type=None,
                              value_type=None,
                              oneof_fields=None, # Not supporting templating with oneof_fields !
                              extensions=None)

# Packing all fields for [webezy_PubSubPackage_v1_ConsumeTopic]
_msg_fields_webezy_PubSubPackage_v1_ConsumeTopic = [_field_webezy_PubSubPackage_v1_ConsumeTopic_topic,_field_webezy_PubSubPackage_v1_ConsumeTopic_topics]
# Packing all fields for [webezy_PubSubPackage_v1_PublishEvent]
_msg_fields_webezy_PubSubPackage_v1_PublishEvent = [_field_webezy_PubSubPackage_v1_PublishEvent_timestamp,_field_webezy_PubSubPackage_v1_PublishEvent_topic,_field_webezy_PubSubPackage_v1_PublishEvent_event]
# Packing all fields for [webezy_PubSubPackage_v1_Topic]
_msg_fields_webezy_PubSubPackage_v1_Topic = [_field_webezy_PubSubPackage_v1_Topic_name]
# Packing all fields for [webezy_PubSubPackage_v1_CreateTopicResponse]
_msg_fields_webezy_PubSubPackage_v1_CreateTopicResponse = [_field_webezy_PubSubPackage_v1_CreateTopicResponse_status]
# Packing all fields for [webezy_PubSubPackage_v1_PublishEventResponse]
_msg_fields_webezy_PubSubPackage_v1_PublishEventResponse = [_field_webezy_PubSubPackage_v1_PublishEventResponse_status]
# Packing all fields for [webezy_PubSubPackage_v1_DropTopicResponse]
_msg_fields_webezy_PubSubPackage_v1_DropTopicResponse = [_field_webezy_PubSubPackage_v1_DropTopicResponse_topic]
# Packing all fields for [webezy_PubSubPackage_v1_DropTopicRequest]
_msg_fields_webezy_PubSubPackage_v1_DropTopicRequest = [_field_webezy_PubSubPackage_v1_DropTopicRequest_topic,_field_webezy_PubSubPackage_v1_DropTopicRequest_force]
    
# Construct messages

# Constructing message [webezy_PubSubPackage_v1_ConsumeTopic]
_msg_webezy_PubSubPackage_v1_ConsumeTopic = helpers.WZMessage(name='ConsumeTopic',
                                 description='This is a client response message for starting consume from a topic',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_ConsumeTopic,
                                 extension_type=None,
                                 extensions=None)

# Constructing message [webezy_PubSubPackage_v1_PublishEvent]
_msg_webezy_PubSubPackage_v1_PublishEvent = helpers.WZMessage(name='PublishEvent',
                                 description='This is the publisher event message',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_PublishEvent,
                                 extension_type=None,
                                 extensions=None)

# Constructing message [webezy_PubSubPackage_v1_Topic]
_msg_webezy_PubSubPackage_v1_Topic = helpers.WZMessage(name='Topic',
                                 description='This is an object representing a topic',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_Topic,
                                 extension_type=None,
                                 extensions=None)

# Constructing message [webezy_PubSubPackage_v1_CreateTopicResponse]
_msg_webezy_PubSubPackage_v1_CreateTopicResponse = helpers.WZMessage(name='CreateTopicResponse',
                                 description='A response object from server once topic has been successfully created',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_CreateTopicResponse,
                                 extension_type=None,
                                 extensions=None)

# Constructing message [webezy_PubSubPackage_v1_PublishEventResponse]
_msg_webezy_PubSubPackage_v1_PublishEventResponse = helpers.WZMessage(name='PublishEventResponse',
                                 description='This is a response object from server after publishing an event to topic',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_PublishEventResponse,
                                 extension_type=None,
                                 extensions=None)

# Constructing message [webezy_PubSubPackage_v1_DropTopicResponse]
_msg_webezy_PubSubPackage_v1_DropTopicResponse = helpers.WZMessage(name='DropTopicResponse',
                                 description='This is a response from server once the topic has been dropped successfully',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_DropTopicResponse,
                                 extension_type=None,
                                 extensions=None)

# Constructing message [webezy_PubSubPackage_v1_DropTopicRequest]
_msg_webezy_PubSubPackage_v1_DropTopicRequest = helpers.WZMessage(name='DropTopicRequest',
                                 description='This is a request for dropping a topic from PubSub service',
                                 fields=_msg_fields_webezy_PubSubPackage_v1_DropTopicRequest,
                                 extension_type=None,
                                 extensions=None)

    
# Construct packages

_pkg_webezy_PubSubPackage_v1 = helpers.WZPackage(name='PubSubPackage',
                                                messages=[_msg_webezy_PubSubPackage_v1_ConsumeTopic,_msg_webezy_PubSubPackage_v1_PublishEvent,_msg_webezy_PubSubPackage_v1_Topic,_msg_webezy_PubSubPackage_v1_CreateTopicResponse,_msg_webezy_PubSubPackage_v1_PublishEventResponse,_msg_webezy_PubSubPackage_v1_DropTopicResponse,_msg_webezy_PubSubPackage_v1_DropTopicRequest],
                                                enums=[],
                                                extensions=None)

# Unpacking package [webezy_PubSubPackage_v1]
_pkg_webezy_PubSubPackage_v1_name, _pkg_webezy_PubSubPackage_v1_messages, _pkg_webezy_PubSubPackage_v1_enums, _pkg_webezy_PubSubPackage_v1_ext, _pkg_webezy_PubSubPackage_v1_domain = _pkg_webezy_PubSubPackage_v1.to_tuple()
    
# Add packages

# Adding package [webezy_PubSubPackage_v1]
_pkg_webezy_PubSubPackage_v1 = _architect.AddPackage(_pkg_webezy_PubSubPackage_v1_name,
                                                    dependencies=[],
                                                    description='None',
                                                    domain=_pkg_webezy_PubSubPackage_v1_domain,
                                                    extensions=_pkg_webezy_PubSubPackage_v1_ext)
    
msgs_map = {}

# Add packages messages

for m in _pkg_webezy_PubSubPackage_v1_messages:
	msg_name, msg_fields, msg_desc, msg_opt, msg_domain = m
	temp_msg = _architect.AddMessage(_pkg_webezy_PubSubPackage_v1, msg_name, msg_fields, msg_desc, msg_opt, msg_domain)
	msgs_map[temp_msg.full_name] = temp_msg
    
# Add packages enums

for e in _pkg_webezy_PubSubPackage_v1_enums:
	enum_name, enum_values, enum_desc, enum_domain = e
	_architect.AddEnum(_pkg_webezy_PubSubPackage_v1, enum_name, enum_values, enum_desc, enum_domain)
    
"""Services and thier resources"""
# Construct rpc's

_rpc_webezy_PubSubService_v1_CreateTopic = helpers.WZRPC(name='CreateTopic',client_stream=None,server_stream=None,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.Topic'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.CreateTopicResponse'].full_name, description='Pass in an "Topic" object to create a topic to be consumed by "PubSubService" Clients')
_rpc_webezy_PubSubService_v1_PublishEvent = helpers.WZRPC(name='PublishEvent',client_stream=None,server_stream=None,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.PublishEvent'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.PublishEventResponse'].full_name, description='A simple publication of "PublishEvent" to specific "Topic"')
_rpc_webezy_PubSubService_v1_ConsumeTopic = helpers.WZRPC(name='ConsumeTopic',client_stream=None,server_stream=True,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.ConsumeTopic'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.PublishEvent'].full_name, description='A server stream sourced from a spcified "Topic"')
_rpc_webezy_PubSubService_v1_StreamPublish = helpers.WZRPC(name='StreamPublish',client_stream=True,server_stream=None,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.PublishEvent'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.PublishEventResponse'].full_name, description='Stream a "PublishEvent"(s) on specified "Topic"')
_rpc_webezy_PubSubService_v1_ListTopics = helpers.WZRPC(name='ListTopics',client_stream=None,server_stream=True,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.ConsumeTopic'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.Topic'].full_name, description='Get a streaming list of active "Topic"(s)')
_rpc_webezy_PubSubService_v1_DropTopic = helpers.WZRPC(name='DropTopic',client_stream=None,server_stream=None,in_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.DropTopicRequest'].full_name, out_type=msgs_map[_DOMAIN+'.PubSubPackage.v1.DropTopicResponse'].full_name, description='Drop a specific topic')
        
# Construct services

_svc_PubSubService = helpers.WZService('PubSubService',
                                                methods=[_rpc_webezy_PubSubService_v1_CreateTopic,_rpc_webezy_PubSubService_v1_PublishEvent,_rpc_webezy_PubSubService_v1_ConsumeTopic,_rpc_webezy_PubSubService_v1_StreamPublish,_rpc_webezy_PubSubService_v1_ListTopics,_rpc_webezy_PubSubService_v1_DropTopic],
                                                dependencies=[_pkg_webezy_PubSubPackage_v1.package],
                                                description='None',
                                                extensions=None)

_svc_PubSubService_name, _svc_PubSubService_methods, _svc_PubSubService_dependencies, _svc_PubSubService_desc, _svc_PubSubService_ext = _svc_PubSubService.to_tuple()
        
# Add services

_svc_PubSubService = _architect.AddService(_svc_PubSubService_name,_svc_PubSubService_dependencies,_svc_PubSubService_desc,[],extensions=_svc_PubSubService_ext)
        

for rpc in _svc_PubSubService_methods:
	rpc_name, rpc_in_out, rpc_desc = rpc
	_architect.AddRPC(_svc_PubSubService, rpc_name, rpc_in_out, rpc_desc)
    
# Initalize all code files 
_context = WebezyContext(files=[WebezyFileContext(file='tests/typescript/publisher.ts',code=b'x\x9c\x95W_o\xdb6\x10\x7f\xf7\xa7\xb8\xe4\xc5r\xea\xc8\xe9\x80\xbe8s\xdb\xac\xc9\xb6\x00]\x13\xc4\x1e\xb6!\r\nZ:\xc7l$J#\xa9x^\xe0\xef\xbe;R\xb2\xc4\xd8\xe96\xa2hL\xf2\xfe\xdf\xef\xee\xa8\xd1\xd1Q\x0f\x8e\xe0\xbd\x129\xc2\xfb\x15\xce\xf1\xef\xb5,F\xd7\xd5|Z\xcdgfd\xd1\xd8\x91]\x97h\x12-K;*\xaby&\xcd\x12ul\x8dcL\xeb\x1bY(8\x83\x96\x12\x92L\xa2\xb2\xb0(\xf4\x1e\xb9`1/3a\xd1\xc9xDm\x98\xff$>\x89_\xbb\x13Q\xd9%1\x9e\xe5\xd2\xc2t\x99W\x19>J\x9b,\xe9n\xd4\xeb\xc9\xbc,\xb4\x85\'\xf8\x05\xadH\x85\x15C\x98\xa2~\x94\t^hM\\\x1bX\xe8"\x87\xfe\xfb{]&#\xfe\xef\xf8\xab\xe9\x9f\xb6|S+le\xf6\xd3\x8d\xe6\x95\xcc\xd2\x91\xd1\xc9()\x94\xb1B\xd9\x80W\x18\x83\xf4\xa3\xe1e\x9a"\xc3\x0e\x05E\xc8Tsk\x86\xde\xd7k\x91<\x88{l\xe8\xe3xD\xff|lL\'\xb0\xad\x80#R\x01\xb9T2\x97\xc6\xd6\\\xcd\xb6\xdf\xeb\xc1h\x04\x9f\x84|D\x10e\xa9\x0b\x91,]\x88\x15\xe5\tSHD\x96\xcdI\xa3\x81c8\xbf\x82OW3\xf8\xe9\nf?\x9f\xcd\xe0\xe6\xea\xec\x1c\x0e\x1c\x7f\x86\x16\x8c\xad\xe60!\xbe\x154\x16G\x83Sw\xcdW\xf1\x07\x8d\x94\x9eYQ\xca$zbt\x8c\xfb3\xd2\xe1\x0e\xfa\x9b\x81#\xe4\x15\xdb%\xaa(\xd2h\xc6\x81\xc3]\x017hJ\x8a\x13\x0e`\xf2\xf6\t\xb6\xac\xbc\xea\xf8\xc5Yq\xcf2\x06\xc1\xa53\xe4\xa3\xac\xb5\x9a\xe8\xc9\xf2\xdf\xae!Cwb\xc6\xb7w\x9b\x90\xd5\x99F^qt\xe7\xb8\xcf>\'\x80-\x82\xa7\x1d\xce\x7f\xb5\x8cWGc7\x1e\x89 \xa0F\x11j=\xee\xa2r\x8f\xa6\xae\x06"\x0f\xc5\xb9\xcd\x0fh-j\xb0\x05,\x85J3\xcaySV9R\x81\xa4\x86\xb1"\xccZ% V\x82j\xe5\x15X-\x94!D\xe4\xd0x/\xd5\xfd\x96\x9c$\x11h\x08J\x08\x99|\xc0\xd8i\xb9Z\x90)\x95\xa63\x92\x90b\x89\x8a(\xa9\x1c\xd7t\x08\xc5J\xc1\xa2R\t\x17\xb8\xc8\xa4]\x93e^cs\n\xb9\x90*\x1a\x90s\xbd\xc6+\x0bB\xdf\x1b\x82\x17)K\xd0\x98\x98\xb6\x8f\xb1\xc9(\x18\xd1w\x8c\xb2-])HoJ\x94\r\xc4#\xe6\x1cxQ\x8c\xd3/\xcb\x82\xc8&5a\xecv\xef\x82\xdd\x18\xfaYA\xc0\xe7M\x7f\xd8k\xa2\xfb\xc5U\xd3\x04\x1aZ\xb7}\x17\xec\xc6\xf0\xe6\xe4\xe4\xcd\xeb\x0e\x8f\x83S\x87\xc9\xef\xdf\x85[R\xd8A`\xcb\x9c\xd7\xed\xa8.\xab\xa6;qYy\x7f(\xd6\x97\x8abL%\x03\xc6c\xa3\xc9\'C}\xeb\xf3\xbe\xdatq\x18:\xa7\x86[M,\xb9\x16\xfc\xab\x95\x99K\x89k\x07\xb9x\xe0\xb4\x8b\x06\x04\xbe?\xeb\xba\x0e\x1d\x0e\x04\x1c^{(\x1c:,\x80T\x84\xb5\x85H\xd0\x89\xdcf7k\xebo0\xae9\xbe\xdfSJ\xb7w\x0e\xdf\xf5\xd2h+\xad\x9c\x0b5\x8f\xab\xc1"{\xc4\xa1\xc6\xaf\x98\xd8\xa6 :\x8b}o\xd5Q\x04n\xefN\x03\x82 \x80]\xcf\x12\xb1T\n\xb3\x1di\x01\xd1\xe4\xa5\x86\xe2\xd3\x1e\xf6\x92g\xeb\x7f\xf4\x92=\x8b\xec>+\xb9\xae8\xf0l<\x8f?\xe7*\x14\x0b\xf0z\x01i\x0c\xae)\x0b\t\x85\x8br\xe7N\xf7JkC\x14\x97\x95Y\xd6\xdd\xe9\xd9z\xe6\x03Y\xf0\x1b5\x08\x16\xec\xf5\xbc>9\xa1\x9a#QlR\xb2\xc4\xe4\x01\xe4"\x8c\x17\xdd%Y\xc1\xe5\xe9\xa6\x10#\x96\x9a\x91\x91)\xee$e\xc1\xad\xc3\xa0bb\xb1e\xe3\xd1\x00+\xc68\n\xcd\xaa\x19\x01\x95\xa6\x8e\x00\xd4\xce\xc0\xe3\xc1\xf9\xba\xc4g\xd1\xd8\xc9\xa4C\xe7\xa3\xc88\x8bh/\xeb]\x14\xbd\x10u\xf2%\xea:\x13{\x93\x06/$( \xadT\x9b\xec\xc1\xe9^z\xe7\xd1\xd6\x88\xc6\xb6\x17\x88k\xdcGm\xde\xf6\x10n\x82\x93\xcd\x90\xf2\xd3f\xb0N\xe6\x86\xc7\x02-K\xf9k\xfd\xa0\xf8\xfbYK%\x1d\x82\x86\xe3\x96\xec\x8ea\n\xa1\x9f\x16/\x0cz_\x0e\x9b\x8e\x91\xddI\xd5\xbf\x95w\xb5\xc2\xd4\xeb\xdb\xf6\x158~\xdb\x1f\xeeQ\xd8\x91D\xc6r\xfdm\x01\xee\x91\xf0g\xc5\x90l\xc6\xcd\xae\x13\x9e\x94\x19\xb7\xb6w\xdb\xd27\x0c\xbd\xc1D\x12\xe0\x1bK\x1d\xc8\x8e\xdfB\xf3p`\x91\x1dv\xff\xb8\x8b\xda\xbbx!U\x1aa\xc6 \xc3,v\xaf\xe4\xc9dR\x0f\x8a\x01\x1c\xd0\xefJ\xa5Hd\x98\x0e\xfb?\n\x999]\xc0|\x0e\xd6\xdc\x01\xbdn\xa9\xa0m=m\xcc\x0e\xfaax\xae\xfd\x0b\x9b$h\xb2\x95lW6\x88E\xfd\x02\x0f\x93X3]0\xf5\xb3\xae\xe6$\x8c\x9f\xa6E\x8e\xe742\xc6\x87\xfc\x0b\n\xb2M\x03\xcf\x90\xc3\xcd\xd0\xca\x9c\xe6\x99\xc8\xcb1[KT\x84\xfb\x97\xd3\xff\xea\xae\xb1\x91\\u\xd2\xd9\xe1\xcf\xedL\xfc\xdc\xef\x0fk+\xebA\xbe\x01\xf7*\x02~\xe6\x14z,\xd4z\x10\x02\xd8\xd9\xe4.\xfdK\x87\xf0\x11\xc7q\x97\xe2\x92\x1f))r\x87\xf0t\xd4\x9d\xce>\xde\\\x9c\x9d\xff\xf1\xe5\xe2\xf7\xcb\xe9l\n\xd1\x07\xa1\x88\x9d\x1b-\xac\xea\xd6\xc3\xa5\xc2\r\xae)\x906\x1d\xc7\x94\x1e\x92\xf1\xa0\x8a\x15\xe5\xec\x9e\x06\xca\xb2\xa8\xb2\x14\xe6\x08i\x91T9\xf9E\xfe\xad0\xcb\xf8-\xd4\x8c\xeb\xb3\xeb\xcb\xb6,\xb9\xc98cbg\x1a\x03\xc3\x7fZ\xc4\xa1e\xcf\xbbN\x18\xcf\x83;\x985e\xe4\xba#\x88\x8c\xccM\xd7\x80\x7f\x11^\x0c#$`\x0f\xcb\xbf\x13\xa3Y\xc7\xe9T\x17%U\x94\x9f\x95\xde\xe3\x1d\x16\x86\x13\xd3\xcd\xeaWO\x07P\xe7\xcdq\xf4D\xef\x89\x04\xc7VW\xe8\x8bf\x1ct\x89=\xb32t\xef\xf8\x0eXX\xb9\xadAn\x12[\xad\xbb\xdc<+\xddp8\x96\xfe\xf3Kr\xe6\xd8\x8b\xfa\x9d\xc9\xdf8;\\\xdetO\x11v\xd2\x00z\xdf\xca\x84\'\x08\x99\xdb\x0eL\xe5O\xc5\xfa\x9f\xb97u\xc3\xeeq\xcf&\x97n*\xf5\xfc\xd9</\xd2u\xcf[\\\x7fDufY\x10\xc3\x0b\xea0)L\xfd\x87\xe2\xa0\xb7\x19\xfc\x03)\x08\xcc\x9e'),
WebezyFileContext(file='tests/typescript/subscriber.ts',code=b'x\x9c\xd5W\xdbn\xdbF\x10}\xd7WL\x8c\x06"m\x99T\x8a\xa2\x0fr\x9c:H\x1c Ek\x1b\xb0\x82>\x18\x82\xb3\xa2F\xd6\xc6\xe4\x92\xe0.\xed\xba*\xfb\xed\x9d\xd9%ER7;o-\x91X\xe4\xee\x9c\xb9\x9d\x99\xe12<<\xec\xc1!\x9c)\x91 \x9c=\xe2\x14\xffz\x92ixUL\xaf\x8b\xe9X\x87\x06\xb5\t\xcdS\x86:\xcaef\xc2\xac\x98\xc6R/0\x0f\x8c\xb6\xc0Y\xb5#S\x05\xef\xa1\x91\x84(\x96\xa8\x0c\xcc\xd3|\x8b^0\x98d\xb10hu<`\xae\x19?\x0c\x86\xc1\x1b\xbb"\n\xb3 \xe0\xfbD\x1a\xb8^$E\x8c\x0f\xd2D\x0b\xda\x0b{=\x90I\x96\xe6\x06\x96p\x8d\xf9\x83\x8c\xf0<\xcf\xd3|\x00\xda\x08Sh(a\x9e\xa7\t\xf4\xcf\xee\xf2,\n\xf9\xcf\xf17\xdd?i\xc3\xf6\x08\x86\xd3B\xc6\xb3P\xe7Q\x18\xa5\x8aT*\xd3\x05\x0b\xad\x91nj0\x0b\xa51\xb6E(G\xba\x98\x1a=p\xd1^\x89\xe8^\xdca\r\x08\x82\x90\xfe\xb9\xec\xe8VjY\x03\xc5&\xf4\x93\x8a`^\xa8\xc8\xa64\x11Ry>,{@\x97u\x08nM\x9a\xc9\x08N\xa1?&r\xc6\xfc\xc0X\xbab4\x94\x84bJ{\n\x1f\xa1\xf6\xc3\xf3\xdd\xb6\xfd\x13\x86\xf0\xc5\xc8\xd8Z\xb0\xe4$\xe2^\xaa;\x10@\xb2\r\x959\xea\x8c\xac!1\x95\xd2\xde\xc1\x15\xf9.5\x1e@,\xef\x11\xa42\x98\xcfE\x84V\xe5\xcaY\xaa\x0c\xe7\x0f\x99\x1cU\x88\xb7\x9d$\x04v\xfbf\xf2\xae\x8a\x88\xaf\x1cM\x91+\xebq\x85\xf1<2\x9f\xc6\x0f8\xc8\xf1\x1bF\xc6\x87\xd36\xa0\x0e\xb51G\x01\xdfLN:\x02\x14\xe7gE\xd5c\x16\xd8\x8d,\x12\x0b\xa50\xde\xd0\xd6\x11:\xb5y\x0c~k\x02\xea\x86\xf1\x81rS$h\xf7\x02\xe6\xf5\xd7\xeb\xcb\x0boY\xfa~G/_A\xa5x\x8a\xderc\x93/\x85\x7f\x9a\x11p\xc8\xa3-\xb9\xda\x12\xfbZ\x98\xef\xb3\x0c\xd5\x8cy\xe2X\xb9\xb1lf \x9d\x83q\xd9Aj\xb0\'"-\xa2\xec\x12\xd5vu\xa7\xc6&\xabAV\xe8\x05\xfb\xb5\x19\x14_\xe5`\xeb2r3R<\xd5\xafPO\xcf\x84\xe08v\xf2\xdb-\xed\xb1F!e\xc4\x1e\x92\xc1g\xccT\x8d\x1a\xc4\xe9\x9d\xd7\xbf\x91\x138W3\x9c\x11\xcf9\x8a\x84\x93\xd5\x90\xdd\xdf\xe1F\xb9\xb1\\\xfa\xbd\xf5\xaa\xfbCH\xc3YvI\x7f3\x1cB")\xa7\xccO\xb4\xc0\xe8\x1e\xe4\xbc[k\xb4\x17\xc5\xa9&_\xec\x80\xa0\xe9BH\xd0r\x86\x1b\x05=\x07\xaah\x8d\x8a\x85\xc5\nF\xb4+xDzD\x91\xb3i\xee\x9e"\x8f\xa8y\x05\x15\x86\xeb%K<\xd5G\xb746\xba\xc0v\xf6\x83\x88\xb9\x03\xd0|\xae\x9e\xbc]\xc9\xa5X\xbcv0\x81s\xc9\xdf\xc1CG\xb4PMg\xf8\'\xdb\xd9\xe5\x88VN\xd4\xbe\xed\x10\xaef\x86\xd7\x14\xf0\x16\xc1.\x85\xe5\x80\xf8i\xc8.\xdd\xad\x931\xc4^\x13\x05\xe7\xc6\xa5\x8c\xcb\x84\xb2#\x1e\x89\xe7\xce\xc4;iJ\xa1\x91\x0ch\xc4\x9e\x8bh\xe1UC{=\x89\x1bUi\xb5\xc1\xf1\xbb\xfe\xc0":\xcemzC\x8e\xb4mI5\xf30f+\x18\x07\xf6\x95~zzZ\xbd0Zpf\xcd\xc1_\xd1vA}@\xc8M\xd6\xba\xbe\xfd3\xb1\x1d\x82\xca\x8d\x10r\x11\xfaGV\x8b\xb5\xd4m\x19;=\xdbC\xf2e\xf3\xd3\xaa\x1b5J\x9f\x99\xa7[f\xe6\x95;\x9f\x9c?\xd0\xdbu\xcf@\xb0\t\x94\t\xce06\x82\x92\xf8\xbb0\x8b@L\xb5\xc7o\xa1\x8ft.a\xd5\x01K\xd0\t \xc9\xfc\xe0\x0e\xcd\x98\x9e\xa8\x0f\x8ea%\xd3Z\xdeU\xc0\xad\x14\x92\xc6A\xa2\xc7\xa9\x05\xac\x8co\x89\xb0l\x91NDj\xdc\xcb\xcb\xd1\x04>\xd0\x083\xab\xc9\xee\x98\xb9]+\x1f\xbe\\\xcd:n\x18RQ\xb3\xe4T\x8f\x1c\xa0\xf4\xbf\xb7\x04\xb6\x19\xfa\x9f\xd1\xff\x9fe\xdf\xb5lIg\x16:\xfcV\xaf\xd4v\x97\xb6\r\xd8\xcd Jg\xadV\xe4Fo\xd6\xed0p\x87\xe4\xe0\xe2r|\xfb\xe9\xf2\xcb\xc5\xc7\xfdM\xffj\x02\x17i}\x8c\x98\xa7\x85}\x9d\x1cG\x9dz[{[v\xe7f}}\x7f\xe95(w\x06\xee\x0e\xee\x9d)\xd9\x99\x9a5\x05\xbd\x97\xf7\xd8\x1a\xbc\xec\xd5\n\xf8\x7fsR\xaf\xc9\x9d\x15\xb9\xe0\x95\x91*\x92)\xae\x9c\xe3\x9a\xa3\x93\x00\x95\'\x92\xf2\x99\x1e\xd1\xc9\xa8\x9e<\xf38Mso\x85\x84\xd7|n\x18\xfa\x10\xf2\xaf_\x9f|^\x00\x0c+\xe0k\xf8\xb9\xc1\xd1\xa1\xaf\xa0\xef\xb8\xfd8\x8f\x81\xf4\xe9E\xb85\xf8\x82\xce\x12/\x067\x1a~\xfc\xc9vEo\xa5\x82\xe0\x9e\xbbyK^\xfa\xf0\x0b\x1c\x0c\x0f\xe0\xa8\xda\x1c\xb9_\xd7H\x95\xc7\x8c\xa8o\xbb\x98zuT\xdf9\\\x95!\xc6\xd5\xb7]\\\xbd:\xaa\xefV.V_!\xce\x99#8\x18\xb5\xcd\xd4\xcf5\x9c\x9e\x03\xb7\xdf\xf0I\x8f}\xf8\x9b\x06b\x9d\x97\xa3~b\xbf\x1cm\x99\xb8\x1a\x0el\xd5rA\xb5fS\xbb\xd4\xber\xc7\xd9\xcfY\xf8aIb\xe5W\xaa\xbb\xd2\xff\x17\xc6\\{\xc0'),
WebezyFileContext(file='services/PubSubService.ts',code=b'x\x9c\xcdZms\xdaH\x12\xfe\x0c\xbfb\xe2\xdaZ \x01\xe1\xfb*\x827^Cv}\x15\x1b\x97!{/>W\x10b\x00m\x84\xc4i\x84\x1d\xce\xe1~\xfb\xf5\xcbH\x1a!al\'\xa9\xba\xaa\x14\x8eF3\xdd==\xddO\xbf\x8c\xbc\xe5*\x8cb\xf1 \xaa\x95\x85\x13L}\xf91p\xa2\xcd\x99\xe3\xfb\xcdd\xe4\xcc\xf7d\x10\x0f\xe3H:K/\x98\xe7\xde\ret\'\xa3\xf2w\xbfzSo\xf7\x8d\x92\xc1\x948\xf4\x9c\xd8\x81g^\xdf[\xaf|\xf9\x85\xe7\xa6\x83\xd7\xd2\x99:\x13`\x91\x1f6\xe5\xe3\x91\xbfE^\x9c\x9b\xa8b\'^+\xf8\xcf\xc7 \xde\xac\xe4\xf4w\xde\x06\xaf\xb9\x901\xd0\x8d\x9d\xaa\xd8\x8aY\x14.E\xed\xdd<Z\xb9m\xfci\xfd\xa9j\x9d\xaa\x97\xa8\x04\xc9{\xae\xecGQ\x18\xa5\xb3\xad\xf6:\xf6|\xd5\x968j\xce>]y#\xe0V\x98\xe8\x05\xb1\x8cf\x8e+s\xb4\xaf\xd6\x93!\xfcc\x0e\xbc\x8ffq\x10\xfe\x18\xf4VQ\x18\x87\xaa\x9d\x9b\x95\xd1|-\x1c\xa5)\\9\xeegg.\xcb\x17\xea\x97\xd9\xc2\xfe\x1d\x1co\x7f\xe9\xc5 \xa7^"q(\xaf\x0b\xd2i\xb9\xce\xda\x93\xb5\xe7O\xdb*r\xdbn\x18\x80\xf6ymU~\xa1\xc5x\x06"\x92\xf0*\x90n\xec\x85\x01\x1c\xc1"\x9c*\xd1\x15\xb5\xde\xf5\xe0\xaa&\xbe\x8a\xdau\xfflpy\xd9?\x1b\xd5\x04\xact}G\xa9\xbc:\x04\x88\xe2\xcb%\xcaU\xae<\xad\xff\xb7\x85C?\x11\x0f\xd5\xca\xcd\x92\x98\xdaB\xc5\x11\x98\xe3\xad-\x9c`\x03\x9c*\xd2\xd8\xbd\x9d\xd7EW\x04\xf2>7\xd4\xa9VV\x91w\xe7\xc4R\xc4\xe1\xcas/\x9c\x95-\xe0\xe7-Sm\x02\xcd\x13\xbd\x0cF\xeb\rc>\xd8\xe64\x0c\xfcM\xa6\t\x94\xd6.S\x8c\xc9\xe5\xde\xf3\xbd\xf9"\xfeg\x18\xc8C\x9cH\xf7\xd1\xda\x8d\xc3\xa8\x9eR\xb5K\xe8wY\xed\r\xd4K%^x\xca\xca\xc9\x04d\xd3\xe7je\x0b:\x9aF\xe1j\x84\xfb\xb5\xc5\x0eH\xbc\xcd\xd9\x94\xd5K&^\xcb\x7f\xaf\xa5\x8a\x9bb\xef{\xb5\x02q%\xee\xa1\x0eR\xb8@\xcb\x16;\x1e\xfe\xcd\xc4\x9b\x9a\xf2\x04f\xc0\xc9\x9b\xd8\xb3\x9f\xb6^[\xad4D\x97L\x87\x15\x0b>@G\xde\x14\xb30"\xb7\xec\n\xa4\r\xba#i\xe0\x00*\xdeL\xd4i\x12\xab\x96\x9fQ\xbf\x89\xb1X\x0bG\xf1\x0c+p\x96\xb2\xa1\xe7\xc1\xc4:QM\x9e+\xbe\x04\xbf\x91K\x96\t8\xe5\xa9\xccelR\xe1%\xe9t\x8b\xbd\x17\x04[\x86w\xf2\xd4\xf7?x*\x96\x81\x8cT\x9d\x1d\xbb\x96\xac\xc8\x11\x9dJ`*\x8btq\xf7\xa1/-?\x9c\xd7\xc77\xad[\x81\xba\x02\x07cu0\x1e,\x9d\x95h\x9d\x88\x9f\x1e\xb2\xd5\xdbq\xe9z/[?\xd2\x9cy\xe5_\x87\x83K\x8b\x8d\xdb\x9bm\xea\xe9n\x1aH\x88)\x81\x96\x06\x93?\xc1*\xad\xcfr\xa3\xb2)\xd6J\xc2\xe6\x1a\x96/\x83y\xbc\x10\'\xe28\xd5c\x8e{\r\xb9\xa3\x15\x00\x0f\xe6\x0e\xbfbd\xb8X\xa2\x19\xad\x1a\xe3\x8d\xa5r:of\xf2\xf1\x8a\xad\xde\xac\xb6\xb6z\xb0\x86h\xc3\xea\xb0\r\xa5\xf0\xec\xad\x90\xbe\x92\x89\x8c\xd9\x1apf3\xe6\xd49\x90Y\xa7\xbf\x0e\xaeG\xfd^s|:\x01<\x05\xcd\xa1?\n\x00u\x88)\n\xcdQ\xdc\xe44\x7f+^\x89+\x87_\xb9\x00\x1b\x00\n\x00\x9f3\xb1\t\xd7\xe2\x1e\xc0\x19NN\x1b1\x11\xba_\xc8@\xf8\xde\x9d\x14\xa8\xac\xf5\x12t)\x9c\x88\x9e\x10\x02\xe8\xa4\xf9\xb0\xadqCo\x80~\xab\xbb[9\xb8\x93\xcb\xc1\xe8\xd3\xfb\xc1\xc7K\xd8\x0b\xeb\x7fW\xf0 \x8cA\xb4u0\x15a \xc0\xaf@\xf0W\x9a)\xf24\xb9\x1dd\xf6\xfe\xf4\xfcC\xbf\xf7\xe9\x8aBK\xef|t>\xb8l\x8e/\xd6\xe0\xca+T\x8e\xa3\r8$\x93\xc2=\xa26\x98\x19\xf2\x02\xe8\xc3\xf8\xd0n\x8bw\x10\xe6\xc4\xbbw\xf7r"\xff\xb3\xf1B\xd1\x12\xbd\x81\x80\xad\x88\xeb\xfe\xc5\xe0\x8f>\xa0\xf5z\xe2\x03%\x170>\x96O\x02\xca\x11CI~\xf0,[\xff\x12||2\xcd\xa7\xc3b\xd9j\x03\x18A7\x08T\x91~e\x97\xc8\x03\xf2?\x08>\x10[\x1c\r\xc3%\xa6i\xe0\x7fGb\xdba\ny\x97Iha@K\x81\x17\x8d\xa3\x04p\xab\xfb\x10\xd6\xc4\xd6\xc3\xde\xf5\xe1\xba\x7f\xda\xfb\xc7\xa7\xfe\xdf\xcf\x87\xa3\xa1a\x98\xda$O}\x0c\xdd\x1b!\xbf\x00\x8c*p\xad\x96\x18E\x1bH\x1f\xa6\xfa\xc0)\x08\x03D\x886\xfbS\xbc\xd0\xd9\x81\xb8\xf7\x00\x8e\xd2\xd0Ro\x88\xeb\xab3m`\xa6!\xe7 \xea\xf5\xad8\x0fRP\x12\x14\xf8k\xcd"\x1ee\xfb\xac\x16\xa0\x1c\xb1\x8aP\x8a\xdd\x92\xe3\x81\xbd\x9b\xcc\xd4\x1bMzM\xe8i?\xc2A\xfc"\x8ao\xe7\x9aG\x83\xd1W\xd8\xe2a\xdb\xd4(\xe0.\xa4}s\xcbO>hH\xc5\xc4\x1c\x0cL\xd6\x1b \xe6\xf9p\xc0VPg\xcf6\xb6`\xb2\xd0\x11\x89\xb8tv55\xbeys+\xd8>u(\xe18B\xa7\xf6\xaf\xa0\x18P\n\x11\xd4\x90\xbe\xa1\xa3\xd5\x0e|k\xbb\x1d\x9f\x81\x85\x00\x00\xb7F\x83\xab\xf3\xb3\xcc4\xc6[\x8d\x15\xdbg\xc1\x04\xfdQ\x0b:\x8aC8qe\xcc\xddum\xf3\xddK\xf0\xe2\xd9\xb4\x9f\x8e\x1b\xa5\xcb\xf3\xc0q-]O\xdeAe9\x17X\x8eq\x1e\xa1U#\xa3B\xd6E6\xdc\x8c\xbd%\x18\x93\xb3\\\x95\xa3A\xde>\xc0\x930\xbc$K~\xc9\x1b\xde\xf6\xd6N\x82\x0f8\xf9o\x10w\x88\x05\xf8w\xc1t\xe8E\x92\x87\x80\xe8\xe4?\x98C\xf0\x8aU\xa8\x947\x81\xcc\xdeu\x02!\xe1\x9dX\xae\xfd\xd8\x83j\x85\'(\x01\x11\xda]8^\x80\xd0\xb0\x14\xf0w\x19R|\xc5\x8a\xe6\x8bP\xae\x045z\xa1*\xc53\xb4Ts\xa3\x96N0_u\xbb\x02\xe2\xa4\x9cy\x81\x9cj\xac{\xd2\xca$=DI\x93\x84\xb0i\xce#O8\x9c\x80\x96\x90\xae\xe6\xd2P\xc2\x01k\xb5V\x8bz\x81|6\x8b\xf1a\xe74\xad}\xa7V\x8euEQ\x9a"\x9f\xa0\xb5_\xbf\x16\xf8\x17\xaa\xe4K8j\x07\xcb1\x1f7\x05\xa78\x0f\xf1\x17\xf2\r\xb0;iYV2\x11`\x18g\xb5\xee\xc3\xc8\x9f\xc2\x124\xd3\x89\x03\xa8}\x1fy\x80\xfaj\x11\xaea|\xe1@2\x1b\x08g\x86\x15\xa3L,\x03c\x00[\x07\xe4\x15j=Qn\xe4M\x10&5\xedaH\x1a\x15G\xe0E\xf1\x91\x0e\x90d@\x13\xa0\x1cb\xb1J\x06\x06A"\x93\xa8-\x12\x10\xa4\x98kC\x92\x17\xc5\x9e\xf3\x98_\x9b\xb8\xf0@\x11\xb7\x02+-\xcd\xaf+\xc6\xfd?\xfa\x97\xa3\xd6\xd5\xc7_?\x9c\x0f\x7f\xef\xf7D\xe6\x13cr)vU"Bi3l\xc7\xa5~P\x11.\x9f\x00!\x16z9z\x17\x14\xa8\xaaA\xa0\xfe\xb4\x94n\xb8?\x7f,\x1e~i\x1e\x99K\xec\x9e\x97\xd6qV\x9c\xcb\xebJ\xfa^\xbb\xa9\x93\xb1\xea1\xd5\x94!v\xbe\xa3\xf5R\xc2\xfb*\xd8\xd2\xd25\x0f\x9d\xff\x85\xd0Jl\xf0\xc8\xb3\xc2n+&\x1b~\xa4\xe5\x80\x02W\x12\xf3\x08\x8e\x9e\xa0\xd23}\x80PSx\xee\x02\xf2\x1f\xdfG\x83\x06\xe7\x9d\xcf\xc1\xb9\xa6T\xacH\xc0\x05\xca\x994\xdakG!\xdf\x91\xd3T\xda\xc4\x18P?4\xc3\xde\xbf\xd7t\xa3(\xc4)\x80\xad\x84u\xc8\x0b\xa3;\x1c,\xc0*[-\xfc\t\x15\xc8\x91\xf5D\xc4=\x94A\xa0\x84(\xdc\x18^\xeb\xeb\x92\x99\xf0\x06\xb2=N\xa4\x10\x14\x89\xa2\xd6_\xaa\x00z\x0b\xac\xcfgF\xf6\x17\xce41\xf0s\x85\x19\xac\xa3\x0c(@\xab\x04\xc2\x8c%)Td\xbe\x85\xd5.\r\xb3M\x8b.\xe0\xbd\xd9[\xd8=\xb2\x9f\x1eP20}\x8c{W\\\x1bf1\x8a\x0e\xcd \x97V\xe7Ol4\x14z\x0c\x946\xdd\xe4\xb5p\x0b\xeb5\x8f=\xf0\xdd)k<\xa4\x95u\xa1\xa8&\xf2\xa4\xa1\xba.\xa5\x8d-pJ\xa0Gv\xd2\x03{W\x0eHawGl\x91\xe5\xa4[\xa3\xac\xdd\xc2\xd9\xc6`\xa1u\xea\xf0\xdaN\xb0i\x18\xe5\xad\xa5m\xe5`\xb1^C\x9d\xe0\xd1\xa7A\xba\xa6\x8bgT\xb9L[\x8cE\x85\x1b{\xe4\x05zr\x12\xb8\xc3\xd9,\x17\xb7\xd1IR\x0b$rfO\xf3\x91\xe9\x85\xce\xce5v\x8c\xd0h\x12\xf3\xdfg7T\x8bwt:D\x9dV/\xc9\xe3h\xf27g2\x87t\xb4\'\xf9x\x8e5\x1f\xb6\xe5}5K\xa7<\x0b)\xb3\xe1\xdd\xa3\x0bJ\x8eB\xc3V\xaaF\xf9\xc5\x95+\x84&\xc5E&"\x96\xce$\x93 I\x84\xe8E\xad)\xea\x19\xfa\x15\x8f\xf4\x8c\xf1N\xe3\x0e\x91\x1d\x97Z\x15w\x0b\x93Va\xb9\xc5lY\xd8T\x02\xbe\x03i\xa2\xa7\xb0\x9f\xec\x97\x83/Q\x9c\x18\xfb\xef\x10\xd3\xd0\xaa\xa2\xc8\x02_T\x80\xe5\xdb\xef\'\x12\x18\x11\x04\x05\x90\xe91a\xde\xd3\xa4\xef\xa9\x16n\x86\x91M\x8c\xc0$\xcf\xd2\xf0\xc2\x95?Noj\xd4b\xfa\x19\x05r\xa3\xdd,\xe8 \xcc\xbc \x13B\x1f\x8bv\x93!\xdd\x809\xc8\xef\xe3\xe5\xf9\xc5\xd5\x87\xfe\x05d\x8b\x00nG|\x93\x80\xf0\x86\xf47\xe0v\xe9\xf5\x8c\x9c\x1e5\xf0P\x9e\x97d\xb1Y\xe8\x98\x9edY%7\x8f?\xa0>\xce_4\xfe_\x15\xc9\x8ft\xd7\xcc\xd5\xdf\xd6d;\xd4 \xfb\xd1G\x8f\xc1\x86lX}\x9f\xec\x9a\x06\xbfkZ\xcd\x14\x8d\xa3\xc1s!\xa7J\x02\xcd\xcc\x01\xf7-\xe6\xd1-\x00\x1b\xc4\x0e\xae\x9cp\x8b\x98As\xe6\x97\xe5\xd1y\x97\x15_K\xc7\x15\x83$&\xb5uN\x90?\xcb\r\xe6\x98\xf9@D7#i\xef\xd3\x10\x06^4k\xed|\xa5\xaf\x13\xa9\xda\xd7\xb2a\xd5\x1c\xbfO\xb7h\x83L\xc8\x0f\xb3\xd0\xe2Tl\x10\xe2\x1d\x83M2yA\xc9\x14\x95\xcd\xc9\x14\xa7q\x1fS\x85\x12\xa2\x98\x17\xd4j\xd9\x15\x99\xa8\xef\x97 M\x8as\xa7\x82\x0c\x8b\x99$6\xefl \xa5\x93\xbe\xca\x04\xac\xe1sG_\xcc\x18w\x1a\xe5b)}\xcdtrl\\\xde\xed\xdf\xf6~\xc1:\x07%\xdb\x16.X\xf6\x10\xd9Oc\xaba\x1e\xf7b.\xeej\x93m\xbc(\xe4\x1c\xf5\xbci\x90\x84\x15\x08\xfcb\x89\x19sr%\xc8WRX\x07\x91\xa1\x1f\x15\x1b\xde\xc8\r\x80\xb1\x9e\xb6O\xb3\x0b\xef}\xd1\xd3\xfe\x9e\x951\x87b[_\xa5\xeb\x88\x8c\x19L\x1a\x95\xb3\xb4\xdf\xa8\xf9j5\xfdL\x9ft\xdc9>\x8cA\xe2w\xae\x9f\xeaF\xce\x91\xd5\x8c\x00\x84x]\x80m I6\xe5\x02\xc6\x05\xd2\xa7\xaa0\xc6\x02\xd9\xb9s<\x1f7\x95v\xe3\xcb\xebK\xd3\x9b\x8f\xb0DG]\xa5\xc8\x92\xd2\xc5\xd3\x92\x88.Go\x90V\xd3($\nW\xb1T\xa3P\xb5\x8c\x0e\xbe/[.O\x90\x11\xa8b\xf5\x84\xd5\xdc\xe1K\xafqu\x99L2\xf7\x06\xfd!\x85\x04\xba\\\xc1^\x8d\xd2_{\xb4\xd2\xa2\x1c\xd9\xc2\x0f\xef.\x85\x82=\xd7\xea\x8d\x82i\xef\xea\r/\xb0\x99rQu\xa4\xb4\xfc6M\xf5=\xb3\x00\x1c\xe5h\x83\x88b"e\x90t ^%\xe5`\xc5\xf5\xa5\x13\xa5F\x94\xd8\x96y\xd1\x8a6D\xc4\xc0f\xbcLGX\x1d\xa4\x1a\xf4\x02\xd7_\x83l\xe4x\xd4n K\x9aq\xef9\xd5\x9dF\xb6\x92\xd2\xec\xb1\xb3\xce\xd7h\xe2\xe7\x9f\xb3\xda\xe8y\x84\x1a\xf8\xff\x11\xd4\xe0\xe0+o\x9f@\x84m\xc7X\x95\x9e*\x9b\x91\xfe\x80(\xcbI\xd4J\xba\xde\xcc\x93\xd4\xf8c\xcc\xe0\x0bnH\xf9c\xd6\x8d\xd6^\x8c\xa3\xf7|\x07\xbeJz\xb6Y_\x88\xb9\xa4\xa6\xb6\xf3\x85L7\xf9v\xa9\xfcK\x83o33\xdc\x9b\xb9\x18\xe5\x82\xd9\t\x9f\x1fb\x84\xdc\xe7\xd5\xe5\x7f\x8ao-\xe1Q\xfbj\n)\xb2\x95\xf0\x7f\xc4\\\x93\xcf \xf0\x92D\x87P\xd4p\x98~v\x103\x14\xa6\xda\xe4\xcdi\xe9\xe0\x05\xe1\x00\x8a@\x16\xccj#\x99\xc1\x8eu(Oc\xf3\xbes\xc9>%\xcb\x0e\x87v\xd7"\x1bH\xda\n\xc9G\r\xe2\r\x88\xd3\xc2\xa6\x10w#\xc9m\x1c\x06}E\xc9)\xc73\x9c[r\xd4\xe3\x9bW\xd88\xc9>\x96\xc8:q\xc0\xa1\x96tNkI\xc3\xad\xf2\x82\xb6\x86Q\x96\xf2\xa5\xca\xcc\xf3\xf1\x02\xb7.\xfdCMQ\xe9\xe7\x9b`\xc6\xa3\xe1\x8af/\xcc\x18>\xc9\x86\x13\xfe\x07\xbd\xbaa\x81\xb6\xfa %I\xf7H\x146\n\xf4|\n#\x13c\xaalww\xff\xa2NM\xe5im\x98\xd4P \x8d\x00\x13\xc4Of\xb4mk\xd3\x16:E4\xbf\xdd\xc1v3\x84\xa7y\x08\xe8\xc37\x98d=\xc1\xd4\xb4\x97\xbc\xb9toS\x13i\x9dd7\x90Y\xd2#~\x1b\x0cz\xe3\xbd\x1d\xc9FIW\x83_t\x8c\xf8\xcan\x07J\xa2\xfc\x8c\xde+\x1c\xa4\xef~\xe8+D\xeck\xe4\xdc\x8f\xe4\xcf\xc4~,\xca\x96\x7f\xa7\x86\xdfr\xed\xef\xb9u\x0cD5V\xe8\x0b\xf8\xd4\x12\xf8\xd2_\x14\xa7\xdc\xe0\xef\xad\x9eu\xb0\xfb\x06\xc3\x8dRoM\xda\x9c9O\xe5\x8fZS_\xd5\xc0@l\xc79d\xcb>|z\x14\x07s\x18\xcd;\xa7\x95\x98\xef6\xc5_\x8e?\x1d\x1f\x1f\xe30d\xbe\xd5m\xfa\xa1,\xa8 \xf7eks\xe7Y\xff\xa9n;\xff\x03\xf9\xc9\x0e\xd8'),
WebezyFileContext(file='services/index.ts',code=b'x\x9c\xe5Z\xebo\xdb6\x10\xffl\xff\x15\x87`\x80\xa5\xc0s\xd2\x02\xfd"\xd7m\x83$\x1b\ntK\x90\xa4\xd8GW\x0f:f#K\x1aI\xe5\x81\xcc\xff\xfb\x8e\xa4\x9e\x16m\xcb\x89\x9d6[P\xa4\x12y\xbc\xf7\xfdx:\x84\xce\x92\x98\tx\x04\x9f\x91\x80D\x82\xba!\xef\xc3\x1fD\xb8\x81+\xdc>\\\x12vK}r\xcaX\xcc\xc0\xe50\xe6zaL\xe4J\x1f\x8eC\x8a\xa7\xbeF.{8v\xc30_8I\x93\x90\xdc_\nF\xdcY\xbevA\x90\xa7\x17\x92\xfa\xea_\x8c\x8ar\x15\xe60a\xf1\x0cz\x9f\xaeY\xe2\x1f\xc8_\xbf~\xe7\xbda\x97\xe6z&\xb8M9\x9d<\x14\xa4\xa9\xa0a\x95\xe2\xcc\x93:J\x9e\x05\t\xbb\xaf39O\xbdK\xfc\xa7M\xd1z\x14\xb4\x83\x03\x14!b~P#\xea\xe5\x87\xf7\xa5\x17\xf4\xd6\xb9\xeb\xdf\xb8\xd7\xc4|.\xdb\xecu\xfd8\xe2\x02\xc6\'\xa7\xbf\x1d}\xfdr5>;\xbf\xfa|\xf6\'\x8c\xe0\xb1\xdb\xd9\x93\xf6\rn\x08I\xdc\x90\xde\x92\xb1\xa032\x9e\xf1=\x07\xde\xbc=\xc4\x9f~N2\x15"y;\x98\xd1H\x93xD\xdc\x11\x12\x8d\x13\x1a]s\xe3\x81:\xcf8\x15\x9a\xca\xc8\xd5\xbd\xcf\x18\xddQ1\x95\xa42\xf2Hl\xe2\x96\x106\xa3\xa2\xa0\xf41\xe4Jz\xbf;\xefv\xc9\xbd\xf2\x90\x1f\xba\x9cC\x92z<\xf5\x04G;\xbb\x1d\xe5\x03\x96\xfa"f\xd64\xe6\xc2\x01|E\x99\xe8\x86\xbd0F.rq\xaf\x0f\xf2\xbc\x03Q:\xf3\x08\xc3\xbdw\x87\x87\xef\xde\xf4a\x96e\xa3S\xe4%\xeeE\xe4\xaex\xb5l[\xba\xb3#\xa6\x94\x0f$+\xdc\x97\xff\r\xf35\xa5\xd7H\xb1/\xd6f%\xaf\xfc\xb1\xd8\xab\x85~\xec\xeb\x04\xd12\r\xa9c}\xfb\xe5\xb1\x10=w\xb2\x17)l\xfe\xad_-\xac\x01>\xbb\x82|\x8e8\xf1SF,\xbb\xbf\x90\x166j\x80\x8e\xec$\x8c\xde"! y\x10G\xe1\x83\xc1\x05C\x03U\xd5\xb5\xa6\xfd\xaa{M\xfb&\xb3\x1d\x93\xc5C\xd4\xb1\xdb9\xd8\xdf\xefv\xf6\xe1\x13*7\x8d\x83:\xdd\xe0X\x99z\x15\'\xd4WD\x01\xe1>\xa3\x89\xa0q\x04\xe72Ah\x04n\x04=E\xd1\x83\xd8\xfbN|\x01"\x06\xed#p\xf1\x19w\xe4\x8aG@&P:#\x01x\x0f\xd0\xab\x17f\x86#\\I\xb9\xa1Q\x00\n\x8d\xd4k\xe22\xc4\x14F\xfeN\t&E\xad0\x07\xa5j\x9a\xaa\xc8\x87\xdc\xc3j\x8f\x11\x91\xb2\x08+^\xc1\x0ey_\xe7Q1\xf2\x82\xf0\x04\x95$\x1f\xf0\xd8\x01\xfa6\xf5B\xd4\xbeB`ej8&=\xca$\xffX\x86\xd8v6\x10;\xfc\x7f\xc4C\xefI\xdc\xf1\xf0\x1c\x1c\x95\x8f\x934\xf2\x955ZCr\xef\xa7\x02\x15\x8c#\x9f\x80\x98\x12\x90\x97\x02\xa2\nS\x0e\x0b8H\x0c\x83\xb5~\xad%\xc1\xc2e\xf7\xccH;\x95k6\xb7\xc2\x01K]\xac\xce\xc2E\x0b\xff`\xd9\xca\xeb\x95ez-\xf26\xa8n\xc3\xe8\x03\xdc\xc64\xc0<Z\xd0|\xb8\x15\xb5\x11\x11kHZ\x9a\xf1\xf1\x85\xec@v\xed+D]\x11t\x02V\x912\xa3\xd1\x08\xd2( \x13\x1a\x91@_!\x1d\x1d\xeb\xb2\xcdxotF\x19\xb9\xf5r\xad\xa5WJv\x1f(\xf2\x81\x87\xa5\xb2\x9c\xd4\xb6\xf3\xf0\x94\x91\x90\xb7Eg\x0e$\xe4D\xe9\x0e\x99\xee\xad\xe45\xd9\x95\xe1\xd3\x8c\xf5U\xb4\x06V\xcee\x1a\xf1\xe9\xe9-\xb2o\xe0\xca\x11p\xec\x9a\xb0\x0f\xd3\xc9\xe6\xaa\xc5x\xa2\x10\xa38\xd5\x93\x05\xcb\x13\xe2\xd3\t\xe6c\x86?\x9b\x82GC\x8d\xa7cz\x95\x95\x19\xd4\xab\x14\xcb\x8a\xa6J\xb3\x19\xb8\x1b\xe5\xafC\xf7\xd7\x18\x86\x9dB\xb9\xc9\x8b\xad\xb1\xfc\xe9\x01\xde*\xa6\x9blh\x05\xea\xdb\xd0\x7f\x17\xe0\xbe\xa1AK\xd1\xddX"[\x81\xf7\xbaW\x96\xa1\xbcQ\xfe\n\x98O*\xf4/\x82\xf3\x89!\x01\x9e\t\xf4\xc7\xba\xe337\x90GyIr\xfd\x15\xcf\xe3\x94\xf9X\xb1\xea\xcb\xd8EX\x91\xa8\x82\xef\rX\xb9\xd4\xc7\xf4\xc7\xffZxi\xe8\xd0\x06\xe5\xcbq\xc0\x8aX/t\xed\x159\xcb\xea\xa7J\xb3\x0c\xe0\xdb\x89^\xdb\xb9\xbf6\xcf\xbf\x18\xb0\x1b\x00\xbd>dz\x81\x88\xef\x0c\xf1\x9b\xc0\xd8\xde\xb6\xe1V\r\xdb\xf5U\xf0\x1cKQP\xbb*S\xc8\x99\x01\xa7\x9c\xe3\x94\xa7,\x9ez\xb2\xa0\xd4\xccI\xd3\xe9\x99]VR\xa3U\r\xb5\xc1\xbd\x0b\xc0\xdd\xd1l\x06qd\xf5\xe4b\xaf\x0fH\xc9\xd7:D]W\x9dR\xb7AD\xee%\x98s[n\xccm\xc5\x90D\x81\xe4g>\xe0\xc7\xb2\xeb\x13\xc4\xaa\x9d\x90\xe1\x91g\xf0\xc1\xc1/\xfe\x07\xf3YE&i\xecu\\\xd5\x15b\xb7\xbaCt83K\x1bP\x96M\x80\xdd\x85\xbe\xd4\xe26\x02D\xde\x9a\x9a\xa0,\x1b\xe06\xa0\xcc\x84Ne\xc9\xd7\x94\xb1\xb6\xd1\xa1\xafd\xfc\x03:\xc3\xfah\xbd\x1d^\xacS\xfe\xc7\xb5\x85\xed\xad\xd9E\xdfXn\x82\xa5\xcdr\x8cVB\x1f\xc6\x85\x9d-\xcd|\x94\xd25\x17\x1b\xbd\xcb\xe2;\xd0o\xc3\xbc\xd3+X\xceu\xbf\xd6Y\xdb\x01rc\x1c\xeb\x9d_\x8b\x8a\xfdB\xb9P\xe5\xc6\x1b\xe5\xfa;\x11\xb2\xc1Pr\xe4(\x1f\x05\t\xf9U\xe9\xe2\r\x7fK\xf2*\xb5$\\\xfd\x0c\xdd\x9ebS\xbf\xf4K\xe3v\xd2\xe4i\x89\xeb\xba\xbbW\xe3\xe1\x9dvu\xa5\n\x1b\xb4s[\x0c\xe9V\xd1Y\xf1\xde\xb0\xa9)\x92ek\x86\xec\x02\xa9\x9fn\xd9\xaa>-\xa3\xd8I\x83\x166\xfc\xf8\xb4\xf6\xac\xb4\xfc?\xd8\x97\x9d\xb081\x7f^\xca\x1d\xf5\x19\x99\xcd\x05EA\xb5\xc1T\xb0`\x7f\xa1\xb7\x9f9\xa0\xad\xb03Mg\x8b\xede\x85\xb3\xa8\xcef\xe3\xd9\xa6\xf4u\x08\xff\xb3yw\xa7@\xdepO\xeb\xa1\xeb3\xe2\xb6U\xf4nX\xd0j\xe4\xba\x15\xedw\x01\xd9\x9b\x98\xb3\xb4qn&\xfdV\xa6\xadM\x9f,\x9b\xb86\x15X1n\rr\xe2\x17\x99\xb5\x06\x8b\x91_=h\x9d\xe7\x7f&\x83\xdck6\xf6\xf3\xf7\xda_Zt\xe7\xff\x02\xcf\x8d\x19\x9b')]) 

# Creating all code files on target project
for f in _context.files:
	file_system.wFile(file_system.get_current_location()+'/'+f.file,zlib.decompress(f.code).decode(),force=True)

    
_architect.Save()
    