# Copyright (c) 2023 sylk.build

# Permission is hereby granted, free of charge, to any person obtaining
# a copy of this software and associated documentation files (the
# "Software"), to deal in the Software without restriction, including
# without limitation the rights to use, copy, modify, merge, publish,
# distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so, subject to
# the following conditions:

# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
# WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

from sylk.commons.config import parse_project_config
from sylk.commons.pretty import print_info, print_success
from sylk.cli.commands import cloud

def display_configs(path:str,dictionary=False):
    """Displaying all sylk.build configurations - Global | Project | SylkJson
    
    Parameters:
    -----------
    
        path: The path for sylk.json file
        dictionary: True / False for printing the results as dict value. If specified False it will print the values as `proto`
    """
    print_info(parse_project_config(path,proto=True if dictionary == False else False),True,'Sylk Configs')

def refresh_global_token():
    """Setting sylk personal access token at global level
    
    Parameters:
    -----------
    
        token: The sylk.build generated personal access token
    """
    cloud.SylkCloud(token=None)
    print_success('Personal access token has been refreshed')